aboutsummaryrefslogtreecommitdiffstats
path: root/sdkmanager/libs
diff options
context:
space:
mode:
authorRaphael Moll <ralf@android.com>2012-08-21 16:20:55 -0700
committerandroid code review <noreply-gerritcodereview@google.com>2012-08-21 16:20:55 -0700
commitfdcd1d6f7456e53451aa3519a4ef9687262ba3b0 (patch)
tree33c2d7c539525a34ea55d9ebf4e46c80578719e8 /sdkmanager/libs
parent9f8cf6ab2ba53f376aa3818c4c8dded330a39216 (diff)
parent2c94aa62f4016145fce9d8862f66d9c160fbce07 (diff)
downloadsdk-fdcd1d6f7456e53451aa3519a4ef9687262ba3b0.zip
sdk-fdcd1d6f7456e53451aa3519a4ef9687262ba3b0.tar.gz
sdk-fdcd1d6f7456e53451aa3519a4ef9687262ba3b0.tar.bz2
Merge "SDK Lib: fix some javadoc references."
Diffstat (limited to 'sdkmanager/libs')
-rw-r--r--sdkmanager/libs/sdklib/src/com/android/sdklib/build/ApkBuilder.java1
-rw-r--r--sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceManager.java41
-rw-r--r--sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceWriter.java4
-rwxr-xr-xsdkmanager/libs/sdklib/src/com/android/sdklib/internal/avd/AvdInfo.java1
-rw-r--r--sdkmanager/libs/sdklib/src/com/android/sdklib/internal/project/ProjectPropertiesWorkingCopy.java2
-rwxr-xr-xsdkmanager/libs/sdklib/src/com/android/sdklib/internal/repository/NullTaskMonitor.java5
6 files changed, 28 insertions, 26 deletions
diff --git a/sdkmanager/libs/sdklib/src/com/android/sdklib/build/ApkBuilder.java b/sdkmanager/libs/sdklib/src/com/android/sdklib/build/ApkBuilder.java
index ff18c8b..626e61f 100644
--- a/sdkmanager/libs/sdklib/src/com/android/sdklib/build/ApkBuilder.java
+++ b/sdkmanager/libs/sdklib/src/com/android/sdklib/build/ApkBuilder.java
@@ -605,7 +605,6 @@ public final class ApkBuilder implements IArchiveBuilder {
* Adds the resources from a source folder to a given {@link IArchiveBuilder}
* @param sourceFolder the source folder.
* @throws ApkCreationException if an error occurred
- * @throws SealedApkException if the APK is already sealed.
* @throws DuplicateFileException if a file conflicts with another already added to the APK
* at the same location inside the APK archive.
*/
diff --git a/sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceManager.java b/sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceManager.java
index af9dee3..b2abb0f 100644
--- a/sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceManager.java
+++ b/sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceManager.java
@@ -67,7 +67,7 @@ public class DeviceManager {
private String mVendorDevicesLocation = "";
private static List<Device> mUserDevices;
private static List<Device> mDefaultDevices;
- private static final Object lock = new Object();
+ private static final Object sLock = new Object();
private static final List<DevicesChangeListener> listeners =
Collections.synchronizedList(new ArrayList<DevicesChangeListener>());
@@ -151,7 +151,7 @@ public class DeviceManager {
/**
* Returns both vendor provided and user created {@link Device}s.
- *
+ *
* @param sdkLocation Location of the Android SDK
* @return A list of both vendor and user provided {@link Device}s
*/
@@ -164,11 +164,11 @@ public class DeviceManager {
/**
* Gets the {@link List} of {@link Device}s packaged with the SDK.
- *
+ *
* @return The {@link List} of default {@link Device}s
*/
public List<Device> getDefaultDevices() {
- synchronized (lock) {
+ synchronized (sLock) {
if (mDefaultDevices == null) {
try {
mDefaultDevices = DeviceParser.parse(
@@ -190,12 +190,12 @@ public class DeviceManager {
/**
* Returns all vendor provided {@link Device}s
- *
+ *
* @param sdkLocation Location of the Android SDK
* @return A list of vendor provided {@link Device}s
*/
public List<Device> getVendorDevices(String sdkLocation) {
- synchronized (lock) {
+ synchronized (sLock) {
if (mVendorDevices == null || !mVendorDevicesLocation.equals(sdkLocation)) {
mVendorDevicesLocation = sdkLocation;
List<Device> devices = new ArrayList<Device>();
@@ -225,11 +225,11 @@ public class DeviceManager {
/**
* Returns all user created {@link Device}s
- *
+ *
* @return All user created {@link Device}s
*/
public List<Device> getUserDevices() {
- synchronized (lock) {
+ synchronized (sLock) {
if (mUserDevices == null) {
// User devices should be saved out to
// $HOME/.android/devices.xml
@@ -244,6 +244,7 @@ public class DeviceManager {
mLog.warning("Couldn't load user devices: %1$s", e.getMessage());
} catch (SAXException e) {
// Probably an old config file which we don't want to overwrite.
+ // FIXME: userDevicesFile is likely null at this point and below.
String base = userDevicesFile.getAbsoluteFile()+".old";
File renamedConfig = new File(base);
int i = 0;
@@ -266,7 +267,7 @@ public class DeviceManager {
}
public void addUserDevice(Device d) {
- synchronized (lock) {
+ synchronized (sLock) {
if (mUserDevices == null) {
getUserDevices();
}
@@ -276,7 +277,7 @@ public class DeviceManager {
}
public void removeUserDevice(Device d) {
- synchronized (lock) {
+ synchronized (sLock) {
if (mUserDevices == null) {
getUserDevices();
}
@@ -295,7 +296,7 @@ public class DeviceManager {
}
public void replaceUserDevice(Device d) {
- synchronized (lock) {
+ synchronized (sLock) {
if (mUserDevices == null) {
getUserDevices();
}
@@ -309,7 +310,7 @@ public class DeviceManager {
* {@link AndroidLocation#getFolder()}.
*/
public void saveUserDevices() {
- synchronized (lock) {
+ synchronized (sLock) {
if (mUserDevices != null && mUserDevices.size() != 0) {
File userDevicesFile;
try {
@@ -333,8 +334,8 @@ public class DeviceManager {
/**
* Returns hardware properties (defined in hardware.ini) as a {@link Map}.
- *
- * @param The {@link State} from which to derive the hardware properties.
+ *
+ * @param s The {@link State} from which to derive the hardware properties.
* @return A {@link Map} of hardware properties.
*/
public static Map<String, String> getHardwareProperties(State s) {
@@ -360,9 +361,9 @@ public class DeviceManager {
/**
* Returns the hardware properties defined in
- * {@link AvdManager.HARDWARE_INI} as a {@link Map}.
- *
- * @param The {@link Device} from which to derive the hardware properties.
+ * {@link AvdManager#HARDWARE_INI} as a {@link Map}.
+ *
+ * @param d The {@link Device} from which to derive the hardware properties.
* @return A {@link Map} of hardware properties.
*/
public static Map<String, String> getHardwareProperties(Device d) {
@@ -381,11 +382,11 @@ public class DeviceManager {
/**
* Takes a boolean and returns the appropriate value for
* {@link HardwareProperties}
- *
+ *
* @param bool The boolean value to turn into the appropriate
* {@link HardwareProperties} value.
- * @return {@value HardwareProperties#BOOLEAN_VALUES[0]} if true,
- * {@value HardwareProperties#BOOLEAN_VALUES[1]} otherwise.
+ * @return {@code HardwareProperties#BOOLEAN_VALUES[0]} if true,
+ * {@code HardwareProperties#BOOLEAN_VALUES[1]} otherwise.
*/
private static String getBooleanVal(boolean bool) {
if (bool) {
diff --git a/sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceWriter.java b/sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceWriter.java
index 4480745..feed6d4 100644
--- a/sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceWriter.java
+++ b/sdkmanager/libs/sdklib/src/com/android/sdklib/devices/DeviceWriter.java
@@ -47,8 +47,8 @@ public class DeviceWriter {
/**
* Writes the XML definition of the given {@link Collection} of {@link Device}s according to
- * {@value #NS_DEVICES_XSD} to the {@link OutputStream}. Note that it is up to the caller to
- * close the {@link OutputStream}.
+ * {@value SdkConstants#NS_DEVICES_XSD} to the {@link OutputStream}.
+ * Note that it is up to the caller to close the {@link OutputStream}.
* @param out The {@link OutputStream} to write the resulting XML to.
* @param devices The {@link Device}s from which to generate the XML.
* @throws ParserConfigurationException
diff --git a/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/avd/AvdInfo.java b/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/avd/AvdInfo.java
index cdd3f84..9e5c61f 100755
--- a/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/avd/AvdInfo.java
+++ b/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/avd/AvdInfo.java
@@ -19,6 +19,7 @@ package com.android.sdklib.internal.avd;
import com.android.SdkConstants;
import com.android.prefs.AndroidLocation.AndroidLocationException;
import com.android.sdklib.IAndroidTarget;
+import com.android.sdklib.devices.Device;
import java.io.File;
import java.util.Collections;
diff --git a/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/project/ProjectPropertiesWorkingCopy.java b/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/project/ProjectPropertiesWorkingCopy.java
index e13ac5e..21dcc36 100644
--- a/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/project/ProjectPropertiesWorkingCopy.java
+++ b/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/project/ProjectPropertiesWorkingCopy.java
@@ -97,7 +97,7 @@ public class ProjectPropertiesWorkingCopy extends ProjectProperties {
* overridden by the build.properties file.
* </ul>
*
- * @param type One the possible {@link PropertyType}s.
+ * @param type One the possible {@link ProjectProperties.PropertyType}s.
* @return this object, for chaining.
*/
public synchronized ProjectPropertiesWorkingCopy merge(PropertyType type) {
diff --git a/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/repository/NullTaskMonitor.java b/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/repository/NullTaskMonitor.java
index e0defb3..f69e37d 100755
--- a/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/repository/NullTaskMonitor.java
+++ b/sdkmanager/libs/sdklib/src/com/android/sdklib/internal/repository/NullTaskMonitor.java
@@ -18,6 +18,7 @@ package com.android.sdklib.internal.repository;
import com.android.annotations.NonNull;
import com.android.utils.ILogger;
+import com.android.utils.NullLogger;
/**
@@ -25,7 +26,7 @@ import com.android.utils.ILogger;
* <p/>
* This can be passed to methods that require a monitor when the caller doesn't
* have any UI to update or means to report tracked progress.
* A custom {@link ILogger} is used. Clients could use {@link NullSdkLog} if
* they really don't care about the logging either.
*/
public class NullTaskMonitor implements ITaskMonitor {
@@ -39,7 +40,7 @@ public class NullTaskMonitor implements ITaskMonitor {
* This can be passed to methods that require a monitor when the caller doesn't
* have any UI to update or means to report tracked progress.
*
* @param log An {@link ILogger}. Must not be null. Consider using {@link NullSdkLog}.
*/
public NullTaskMonitor(ILogger log) {
mLog = log;
@@ -25,7 +26,7 @@ import com.android.utils.ILogger;
* This can be passed to methods that require a monitor when the caller doesn't
* have any UI to update or means to report tracked progress.
- * A custom {@link ILogger} is used. Clients could use {@link NullSdkLog} if
+ * A custom {@link ILogger} is used. Clients could use {@link NullLogger} if
* they really don't care about the logging either.
*/
@@ -39,7 +40,7 @@ public class NullTaskMonitor implements ITaskMonitor {
* have any UI to update or means to report tracked progress.
*
- * @param log An {@link ILogger}. Must not be null. Consider using {@link NullSdkLog}.
+ * @param log An {@link ILogger}. Must not be null. Consider using {@link NullLogger}.
*/
public NullTaskMonitor(ILogger log) {